/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2024 TypeFox and others.
 * Licensed under the MIT License. See LICENSE in the package root for license information.
* ------------------------------------------------------------------------------------------ */
import * as vscode from 'vscode';
import {} from '@codingame/monaco-vscode-api/extensions';
import React from 'react';
import ReactDOM from 'react-dom/client';
import { MonacoEditorReactComp } from '@typefox/monaco-editor-react';
import { MonacoEditorLanguageClientWrapper } from 'monaco-editor-wrapper';
import { createWrapperConfig } from './config.js';
import { configureDebugging } from '../../debugger/client/debugger.js';
export const runPythonReact = async () => {
    const appConfig = createWrapperConfig();
    const onLoad = async (wrapper) => {
        const result = wrapper.getExtensionRegisterResult('mlc-python-example');
        result.setAsDefaultApi();
        const initResult = wrapper.getExtensionRegisterResult('debugger-py-client');
        if (initResult !== undefined) {
            configureDebugging(await initResult.getApi(), appConfig.configParams);
        }
        await vscode.commands.executeCommand('workbench.view.explorer');
        await vscode.window.showTextDocument(appConfig.configParams.files.get('hello2.py').uri);
    };
    const root = ReactDOM.createRoot(document.getElementById('react-root'));
    const App = () => {
        return (React.createElement("div", { style: { 'backgroundColor': '#1f1f1f' } },
            React.createElement(MonacoEditorReactComp, { wrapperConfig: appConfig.wrapperConfig, style: { 'height': '100%' }, onLoad: onLoad, onError: (e) => {
                    console.error(e);
                } })));
    };
    root.render(React.createElement(App, null));
};
//# sourceMappingURL=reactPython.js.map